window.Gleam.initSearch([{"doc":"glance","title":"glance","content":"# glance\n\n[![Package Version](https://img.shields.io/hexpm/v/glance)](https://hex.pm/packages/glance)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glance/)\n\nA Gleam source code parser, in Gleam!\n\nCurrently this library will parse the following:\n\n- Custom types.\n- Imports.\n- Type aliases.\n\nAll other Gleam syntax is skipped over.\n\n\n## Usage\n\nAdd the package to your Gleam project:\n\n```sh\ngleam add glance\n```\n\nThen get parsing!\n\n```gleam\nimport glance\nimport gleam/io\n\nconst code = &quot;\n  pub type Cardinal {\n    North\n    East\n    South\n    West\n  }\n&quot;\n\npub fn main() {\n  let assert Ok(parsed) = glance.module(code)\n  io.debug(parsed.custom_types)\n}\n```\n\nThis program print this to the console:\n  \n```gleam\n[\n  CustomType(\n    name: &quot;Cardinal&quot;,\n    publicity: Public,\n    parameters: [],\n    variants: [\n      Variant(&quot;North&quot;, []),\n      Variant(&quot;East&quot;, []),\n      Variant(&quot;South&quot;, []),\n      Variant(&quot;West&quot;, []),\n    ],\n  ),\n]\n```\n\nAPI documentation can be found at &lt;https://hexdocs.pm/glance&gt;.\n","url":"index.html"},{"doc":"glance","title":"Constant","content":"pub type Constant {\n  Constant(\n    name: String,\n    publicity: Publicity,\n    annotation: Option(Type),\n    value: ConstantExpression,\n  )\n}\n\nConstant(\n  name: String,\n  publicity: Publicity,\n  annotation: Option(Type),\n  value: ConstantExpression,\n)\n\n\nSynonyms:\nglance.Constant\nglance Constant","url":"glance.html#Constant"},{"doc":"glance","title":"ConstantExpression","content":"pub type ConstantExpression {\n  ConstantBitString\n  ConstantInt(String)\n  ConstantFloat(String)\n  ConstantString(String)\n  ConstantVariable(String)\n  ConstantTuple(List(ConstantExpression))\n  ConstantList(List(ConstantExpression))\n  ConstantConstructor(\n    name: String,\n    module: Option(String),\n    parameters: List(Field(ConstantExpression)),\n  )\n}\n\nConstantBitString\n\n\nConstantInt(String)\n\n\nConstantFloat(String)\n\n\nConstantString(String)\n\n\nConstantVariable(String)\n\n\nConstantTuple(List(ConstantExpression))\n\n\nConstantList(List(ConstantExpression))\n\n\nConstantConstructor(\n  name: String,\n  module: Option(String),\n  parameters: List(Field(ConstantExpression)),\n)\n\n\nSynonyms:\nglance.ConstantExpression\nglance ConstantExpression","url":"glance.html#ConstantExpression"},{"doc":"glance","title":"CustomType","content":"pub type CustomType {\n  CustomType(\n    name: String,\n    publicity: Publicity,\n    parameters: List(String),\n    variants: List(Variant),\n  )\n}\n\nCustomType(\n  name: String,\n  publicity: Publicity,\n  parameters: List(String),\n  variants: List(Variant),\n)\n\n\nSynonyms:\nglance.CustomType\nglance CustomType","url":"glance.html#CustomType"},{"doc":"glance","title":"Error","content":"pub type Error {\n  UnexpectedEndOfInput\n  UnexpectedToken(token: Token, position: Position)\n}\n\nUnexpectedEndOfInput\n\n\nUnexpectedToken(token: Token, position: Position)\n\n\nSynonyms:\nglance.Error\nglance Error","url":"glance.html#Error"},{"doc":"glance","title":"Field","content":"pub type Field(t) {\n  Field(label: Option(String), item: t)\n}\n\nField(label: Option(String), item: t)\n\n\nSynonyms:\nglance.Field\nglance Field","url":"glance.html#Field"},{"doc":"glance","title":"Import","content":"pub type Import {\n  Import(\n    module: String,\n    alias: Option(String),\n    unqualified: List(UnqualifiedImport),\n  )\n}\n\nImport(\n  module: String,\n  alias: Option(String),\n  unqualified: List(UnqualifiedImport),\n)\n\n\nSynonyms:\nglance.Import\nglance Import","url":"glance.html#Import"},{"doc":"glance","title":"Module","content":"pub type Module {\n  Module(\n    imports: List(Import),\n    custom_types: List(CustomType),\n    type_aliases: List(TypeAlias),\n    constants: List(Constant),\n  )\n}\n\nModule(\n  imports: List(Import),\n  custom_types: List(CustomType),\n  type_aliases: List(TypeAlias),\n  constants: List(Constant),\n)\n\n\nSynonyms:\nglance.Module\nglance Module","url":"glance.html#Module"},{"doc":"glance","title":"Publicity","content":"pub type Publicity {\n  Public\n  Private\n}\n\nPublic\n\n\nPrivate\n\n\nSynonyms:\nglance.Publicity\nglance Publicity","url":"glance.html#Publicity"},{"doc":"glance","title":"Type","content":"pub type Type {\n  NamedType(\n    name: String,\n    module: Option(String),\n    parameters: List(Type),\n  )\n  TupleType(elements: List(Type))\n  FunctionType(paramters: List(Type), return: Type)\n  VariableType(name: String)\n}\n\nNamedType(\n  name: String,\n  module: Option(String),\n  parameters: List(Type),\n)\n\n\nTupleType(elements: List(Type))\n\n\nFunctionType(paramters: List(Type), return: Type)\n\n\nVariableType(name: String)\n\n\nSynonyms:\nglance.Type\nglance Type","url":"glance.html#Type"},{"doc":"glance","title":"TypeAlias","content":"pub type TypeAlias {\n  TypeAlias(\n    name: String,\n    publicity: Publicity,\n    parameters: List(String),\n    aliased: Type,\n  )\n}\n\nTypeAlias(\n  name: String,\n  publicity: Publicity,\n  parameters: List(String),\n  aliased: Type,\n)\n\n\nSynonyms:\nglance.TypeAlias\nglance TypeAlias","url":"glance.html#TypeAlias"},{"doc":"glance","title":"UnqualifiedImport","content":"pub type UnqualifiedImport {\n  UnqualifiedImport(name: String, alias: Option(String))\n}\n\nUnqualifiedImport(name: String, alias: Option(String))\n\n\nSynonyms:\nglance.UnqualifiedImport\nglance UnqualifiedImport","url":"glance.html#UnqualifiedImport"},{"doc":"glance","title":"Variant","content":"pub type Variant {\n  Variant(name: String, fields: List(Field(Type)))\n}\n\nVariant(name: String, fields: List(Field(Type)))\n\n\nSynonyms:\nglance.Variant\nglance Variant","url":"glance.html#Variant"},{"doc":"glance","title":"module","content":"pub fn module(src: String) -&gt; Result(Module, Error)\n\nSynonyms:\nglance.module\nglance module","url":"glance.html#module"},{"doc":"glance","title":"glance","content":"","url":"glance.html"}]);